==> api-0.16.0-sources.jar: io/strimzi/api/kafka/model/listener/RouteListenerOverrideFluent.java <==
package io.strimzi.api.kafka.model.listener;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface RouteListenerOverrideFluent<A extends RouteListenerOverrideFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildBootstrap instead.
 * @return The buildable object.
 */
@Deprecated public RouteListenerBootstrapOverride getBootstrap();
    public RouteListenerBootstrapOverride buildBootstrap();
    public A withBootstrap(RouteListenerBootstrapOverride bootstrap);
    public Boolean hasBootstrap();
    public RouteListenerOverrideFluent.BootstrapNested<A> withNewBootstrap();
    public RouteListenerOverrideFluent.BootstrapNested<A> withNewBootstrapLike(RouteListenerBootstrapOverride item);
    public RouteListenerOverrideFluent.BootstrapNested<A> editBootstrap();
    public RouteListenerOverrideFluent.BootstrapNested<A> editOrNewBootstrap();
    public RouteListenerOverrideFluent.BootstrapNested<A> editOrNewBootstrapLike(RouteListenerBootstrapOverride item);
    public A addToBrokers(int index,RouteListenerBrokerOverride item);
    public A setToBrokers(int index,RouteListenerBrokerOverride item);
    public A addToBrokers(RouteListenerBrokerOverride... items);
    public A addAllToBrokers(Collection<RouteListenerBrokerOverride> items);
    public A removeFromBrokers(RouteListenerBrokerOverride... items);
    public A removeAllFromBrokers(Collection<RouteListenerBrokerOverride> items);
    public A removeMatchingFromBrokers(io.fabric8.kubernetes.api.builder.Predicate<RouteListenerBrokerOverrideBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildBrokers instead.
 * @return The buildable object.
 */
@Deprecated public List<RouteListenerBrokerOverride> getBrokers();
    public List<RouteListenerBrokerOverride> buildBrokers();
    public RouteListenerBrokerOverride buildBroker(int index);
    public RouteListenerBrokerOverride buildFirstBroker();
    public RouteListenerBrokerOverride buildLastBroker();
    public RouteListenerBrokerOverride buildMatchingBroker(io.fabric8.kubernetes.api.builder.Predicate<RouteListenerBrokerOverrideBuilder> predicate);
    public Boolean hasMatchingBroker(io.fabric8.kubernetes.api.builder.Predicate<RouteListenerBrokerOverrideBuilder> predicate);
    public A withBrokers(List<RouteListenerBrokerOverride> brokers);
    public A withBrokers(RouteListenerBrokerOverride... brokers);
    public Boolean hasBrokers();
    public RouteListenerOverrideFluent.BrokersNested<A> addNewBroker();
    public RouteListenerOverrideFluent.BrokersNested<A> addNewBrokerLike(RouteListenerBrokerOverride item);
    public RouteListenerOverrideFluent.BrokersNested<A> setNewBrokerLike(int index,RouteListenerBrokerOverride item);
    public RouteListenerOverrideFluent.BrokersNested<A> editBroker(int index);
    public RouteListenerOverrideFluent.BrokersNested<A> editFirstBroker();
    public RouteListenerOverrideFluent.BrokersNested<A> editLastBroker();
    public RouteListenerOverrideFluent.BrokersNested<A> editMatchingBroker(io.fabric8.kubernetes.api.builder.Predicate<RouteListenerBrokerOverrideBuilder> predicate);

    public interface BootstrapNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,RouteListenerBootstrapOverrideFluent<RouteListenerOverrideFluent.BootstrapNested<N>>{

        
    public N and();    public N endBootstrap();
}
    public interface BrokersNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,RouteListenerBrokerOverrideFluent<RouteListenerOverrideFluent.BrokersNested<N>>{

        
    public N and();    public N endBroker();
}


}

==> api-0.21.0-sources.jar: io/strimzi/api/kafka/model/listener/RouteListenerOverrideFluent.java <==
package io.strimzi.api.kafka.model.listener;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface RouteListenerOverrideFluent<A extends RouteListenerOverrideFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildBootstrap instead.
 * @return The buildable object.
 */
@Deprecated public RouteListenerBootstrapOverride getBootstrap();
    public RouteListenerBootstrapOverride buildBootstrap();
    public A withBootstrap(RouteListenerBootstrapOverride bootstrap);
    public Boolean hasBootstrap();
    public RouteListenerOverrideFluent.BootstrapNested<A> withNewBootstrap();
    public RouteListenerOverrideFluent.BootstrapNested<A> withNewBootstrapLike(RouteListenerBootstrapOverride item);
    public RouteListenerOverrideFluent.BootstrapNested<A> editBootstrap();
    public RouteListenerOverrideFluent.BootstrapNested<A> editOrNewBootstrap();
    public RouteListenerOverrideFluent.BootstrapNested<A> editOrNewBootstrapLike(RouteListenerBootstrapOverride item);
    public A addToBrokers(int index,RouteListenerBrokerOverride item);
    public A setToBrokers(int index,RouteListenerBrokerOverride item);
    public A addToBrokers(RouteListenerBrokerOverride... items);
    public A addAllToBrokers(Collection<RouteListenerBrokerOverride> items);
    public A removeFromBrokers(RouteListenerBrokerOverride... items);
    public A removeAllFromBrokers(Collection<RouteListenerBrokerOverride> items);
    public A removeMatchingFromBrokers(io.fabric8.kubernetes.api.builder.Predicate<RouteListenerBrokerOverrideBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildBrokers instead.
 * @return The buildable object.
 */
@Deprecated public java.util.List<RouteListenerBrokerOverride> getBrokers();
    public java.util.List<RouteListenerBrokerOverride> buildBrokers();
    public RouteListenerBrokerOverride buildBroker(int index);
    public RouteListenerBrokerOverride buildFirstBroker();
    public RouteListenerBrokerOverride buildLastBroker();
    public RouteListenerBrokerOverride buildMatchingBroker(io.fabric8.kubernetes.api.builder.Predicate<RouteListenerBrokerOverrideBuilder> predicate);
    public Boolean hasMatchingBroker(io.fabric8.kubernetes.api.builder.Predicate<RouteListenerBrokerOverrideBuilder> predicate);
    public A withBrokers(java.util.List<RouteListenerBrokerOverride> brokers);
    public A withBrokers(RouteListenerBrokerOverride... brokers);
    public Boolean hasBrokers();
    public RouteListenerOverrideFluent.BrokersNested<A> addNewBroker();
    public RouteListenerOverrideFluent.BrokersNested<A> addNewBrokerLike(RouteListenerBrokerOverride item);
    public RouteListenerOverrideFluent.BrokersNested<A> setNewBrokerLike(int index,RouteListenerBrokerOverride item);
    public RouteListenerOverrideFluent.BrokersNested<A> editBroker(int index);
    public RouteListenerOverrideFluent.BrokersNested<A> editFirstBroker();
    public RouteListenerOverrideFluent.BrokersNested<A> editLastBroker();
    public RouteListenerOverrideFluent.BrokersNested<A> editMatchingBroker(io.fabric8.kubernetes.api.builder.Predicate<RouteListenerBrokerOverrideBuilder> predicate);

    public interface BootstrapNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,RouteListenerBootstrapOverrideFluent<RouteListenerOverrideFluent.BootstrapNested<N>>{

        
    public N and();    public N endBootstrap();
}
    public interface BrokersNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,RouteListenerBrokerOverrideFluent<RouteListenerOverrideFluent.BrokersNested<N>>{

        
    public N and();    public N endBroker();
}


}
